@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # Shared storage for refs that need to survive across threads
 our %_ref_storage;
@@ -111,14 +111,16 @@ B<Doubly> uses an B<ID-based registry>:
 	└─────────────────────────────────────────────────┘
 	            ↑                    ↑
 	       Perl $list1           Perl $list2
-	       { _id=0, _pos=5 }     { _id=1, _pos=0 }
+	       { _id=0, _node_id=5 }   { _id=1, _node_id=1 }
 
-Perl objects store an B<integer ID> and a B<position cursor>, not pointers.
+Perl objects store an B<integer ID> and a B<stable node ID>, not pointers.
 All lists live in a global C registry. Every operation does:
-C<LOCK → lookup by ID → navigate to _pos → operate → UNLOCK>.
+C<LOCK → lookup by ID → find node by _node_id → operate → UNLOCK>.
 When Perl clones an SV across threads, it copies the integers - the actual
 list data stays in place and remains accessible from any thread. Each thread
-gets its own C<_pos> cursor, so threads can navigate the same list independently.
+gets its own C<_node_id> reference, so threads can navigate the same list independently.
+Unlike position-based cursors, node IDs remain valid even after insertions or deletions
+elsewhere in the list.
 
 B<Doubly::Pointer> uses B<raw pointers>:
 
